@@ -12,10 +12,21 @@ logger = logging.getLogger('deeplink.zanox')
 
 class Zanox(BaseDeeplinkGenerator):
     @classmethod
-    def get_tracking_url(cls, url):
+    def get_tracking_url(cls, url, **kwargs):
+        deeplink = ''
+        try:
+            json = cls._req_zanox(url)
+            deeplink = json['url']
+            if not deeplink:
+                logger.error('Error: {}'.format(json))
+        except ConnectionError as e:
+            logger.error('Error: {}'.format(e))
+        return deeplink
+
+    @classmethod
+    def _req_zanox(cls, url):
         url = clear_url(url)
         url = parse.quote_plus(url)
-        deeplink = ''
         req_url = 'http://toolbox.zanox.com/tools/api/deeplink?' \
                   'connectid={connectid}&' \
                   'format=json&' \
@@ -24,11 +35,5 @@ class Zanox(BaseDeeplinkGenerator):
             .format(connectid=ZANOX_CONNECT_ID,
                     adspaceid=ZANOX_ADS_SPACE_ID,
                     url=url)
-        try:
-            r = requests.get(req_url)
-            deeplink = r.json()['url']
-            if not deeplink:
-                logger.error('Error: {}'.format(r.json()))
-        except ConnectionError as e:
-            logger.error('Error: {}'.format(e))
-        return deeplink
+        r = requests.get(req_url)
+        return r.json()
